@@ -321,10 +321,10 @@ class GeneratePPT(Logger):
 
                     hl_summary.add_components(components)
 
-                    if not lic.empty:
-                        lic_summary.add_high(lic.high)
-                        lic_summary.add_medium(lic.medium)
-                        lic_summary.add_low(lic.low)
+#                    if not lic.empty:
+                    lic_summary.add_high(lic.high)
+                    lic_summary.add_medium(lic.medium)
+                    lic_summary.add_low(lic.low)
                 except KeyError as ex:
                     self.warning(f'OSS information not found {str(ex)}')
                 """
