@@ -358,6 +358,7 @@ class AipData(AipRestCall):
         sizing_df = DataFrame(self.sizing(app))
         sizing_df = sizing_df[sizing_df.index.isin(['All'])==False]
         sizing_df = DataFrame(sizing_df["Number of Code Lines"].rename("LOC")).dropna()
+        sizing_df.sort_values(by=['LOC'], ascending=False,inplace=True)
         sizing_df = sizing_df.applymap('{:,.0f}'.format)
         
         tech = sizing_df.join(grade_df) 
@@ -368,7 +369,7 @@ class AipData(AipRestCall):
         sizing_df = sizing_df.applymap('{:,.0f}'.format)
 
         tech = tech.join(sizing_df)
-        tech.sort_values(by='LOC',ascending=False,inplace=True)
+#        tech.sort_values(by='LOC',ascending=False,inplace=True)
 #        tech = tech.applymap('{:,.2f}'.format)
 
         
@@ -427,7 +428,7 @@ class HLData(HLRestCall):
                 self._data[s]['licenses']=lic
                 self._data[s]['cloud']=self.get_cloud_data(app_id)
 
-                if cves.empty:
+                if cves is None:
                     self._data[s]['cve_crit_tot']=0
                     self._data[s]['cve_crit_comp_tot']=0
                     self._data[s]['cve_high_tot']=0
@@ -441,7 +442,8 @@ class HLData(HLRestCall):
                     self._data[s]['cve_high_comp_tot']=len(cves[cves['criticity']=='HIGH']['component'].unique())
                     self._data[s]['cve_med_tot']=len(cves[cves['criticity']=='MEDIUM']['cve'].unique())
                     self._data[s]['cve_med_comp_tot']=len(cves[cves['criticity']=='MEDIUM']['component'].unique())
-                if lic.empty:
+                
+                if lic is None:
                     self._data[s]['lic_high_tot']=0
                     self._data[s]['lic_med_tot']=0
                 else:
